"""
Toolkit setup

This file is run on importing anything within this directory.
Its purpose is only to help with the Gamera GUI shell,
and may be omitted if you are not concerned with that.
"""

from gamera import toolkit
import wx

from gamera.gui import has_gui

# Let's import all our plugins here so that when this toolkit
# is imported using the "Toolkit" menu in the Gamera GUI
# everything works.

from gamera.toolkits.mis_support.plugins import mis_support

if has_gui.has_gui:
    from gamera.gui import gui
    from gamera.gui import gui_util
    from gamera.gui import var_name

    # You can inherit from toolkit.CustomMenu to create a menu
    # for your toolkit.  Create a list of menu option in the
    # member _items, and a series of callback functions that
    # correspond to them.  The name of the callback function
    # should be the same as the menu item, prefixed by '_On'
    # and with all spaces converted to underscores.
    class MISMenu(toolkit.CustomMenu):
        _items = ["Load MIS File"]
        def _OnLoad_MIS_File(self, event):
            filename = gui_util.open_file_dialog(None, "MIS Files (*.MIS;*.mis)|*.MIS;*.mis")
            if filename:
                name = var_name.get("imagelist", gui.main_win.shell.locals)
                if name:
                    try:
                        wx.BeginBusyCursor()
                        gui.main_win.shell.run('%s = mis_support.mis_support.load_MIS(r"%s")' % (name, filename))
                    finally:
                        wx.EndBusyCursor()
    mis_menu = MISMenu()
