/*
# pgrm: shufflemit - takes a mit file and randomly reorders its entries.
# pgrm:
*/

#include <stdio.h>
#include <string.h>
#include <sys/param.h>
#include <ihead.h>
#include <mfs.h>
#include <mis.h>
#include <mit.h>

#define NUM_SHUFFLES 10
#define DEFAULTSEED 1234

main(argc, argv)
int argc; char **argv;
{
   int seed, i, j, k, clstoo, mittoo, mitundo, num, misindex;
   MFS *names, *mrg, *cls;
   MIT *mit, *undo;
   MIS *inp, *out;
   char **newvalues, tmp[MAXMITLENGTH], class[MAXMFSLENGTH];
   char clsfile[MAXPATHLEN],  mitfile[MAXPATHLEN], misfile[MAXPATHLEN];

   procargs(argc, argv, &names, &seed, &clstoo, &mittoo, &mitundo);

   for ( j = 0 ; j < names->num ; j++ )
   {
      srandom(seed);
      inp = readmishdr(names->values[j]);
      num = inp->ent_num;
      freemishdr(inp);

      if (clstoo)
      {
         strcpy(clsfile, names->values[j]);
         newext(clsfile, MAXPATHLEN, "cls");
         cls = readmfsfile(clsfile);
         if (cls->num != num)
            fatalerr(argv[0], clsfile, "unequal num entries to .mis file");
      }

      mrg = allocmfs(num);
      for ( i = 0 ; i < num ; i++ )
      {
         if (clstoo)
            sprintf(tmp, "%s %d %s", names->values[j], i, cls->values[i]);
         else
            sprintf(tmp, "%s %d", names->values[j], i);
         appendmfs(mrg, tmp);
      }

      newvalues = (char **)shuffle_strings(NUM_SHUFFLES, mrg->values, mrg->num);
      freemfs(mrg);

      if (clstoo)
         freemfs(cls),
         cls = allocmfs(num);

      mit = allocmit(num);
      for ( i = 0 ; i < num ; i++ )
      {
         if (clstoo)
            sscanf(newvalues[i], "%s %d %s", misfile, &misindex, class),
            appendmfs(cls, class);
         else
            sscanf(newvalues[i], "%s %d",    misfile, &misindex       );
         appendmit(mit, misfile, misindex);
      }
      free_names(newvalues, num);

      if (mittoo)
         strcpy(mitfile, names->values[j]),
         newext(mitfile, MAXPATHLEN, MIT_EXT),
         writemitfile(mitfile, mit);
   
      out = misfrmit(mit);
      set_compression(out->head, CCITT_G4);
#ifdef CHANGE_EXTENSION
      strcpy(misfile, names->values[j]),
      newext(misfile, MAXPATHLEN, "shf"),
      writemisfile(misfile, out);
#else
      strcpy(misfile, names->values[j]),
      writemisfile(misfile, out);
#endif

      if (mitundo)
      {
          undo = allocmit(num);
          for ( i = 0 ; i < num ; i++ )
          {  /* To invert the shuffle we must find the indices of where   */
             /* the chars went so this is a linear search to do that. Not */
             /* pretty but functional. */
             for ( k = 0 ; k < num ; k++ )
             {
                sscanf(mit->values[k], "%s %d", tmp, &misindex);
                if (misindex == i)
                {
                   appendmit(undo, misfile, k);
                   break;
                }
             }
          }
          strcpy(mitfile, names->values[j]);
          newext(mitfile, MAXPATHLEN, "bak");
          writemitfile(mitfile, undo);
          freemit(undo);
      }

      freemit(mit);
      freemis(out);
      if (clstoo)
         writemfsfile(clsfile, cls),
         freemfs(cls);
   }
   freemfs(names);
}


procargs(argc, argv, names, seed, clstoo, mittoo, mitundo)
int       argc; int *seed, *clstoo, *mittoo, *mitundo;
char    **argv; MFS **names;
{
extern int getopt(), optind;
extern char *optarg;
int c, nmisfiles;

   if (argc < 2)
      usage(argv);

   *clstoo = *mittoo = 0, *mitundo; *seed = DEFAULTSEED;
   while ((c = getopt(argc, argv, "cmus:")) != -1)
      switch (c)
      {  
          case 'c' : *clstoo = 1; break;
          case 'm' : *mittoo = 1; break;
          case 's' : sscanf(optarg, "%d", seed); break;
          case 'u' : *mitundo = 1; break;
          default  : usage(argv);
      }

   if ((nmisfiles = argc - optind) < 1)
      usage(argv);

   *names = allocmfs(nmisfiles);
   for ( c = 0 ; c < nmisfiles ; c++ )
      appendmfs(*names, argv[optind++]);
}

usage(argv)
char **argv;
{
   fprintf(stderr, "Usage: %s:\n", argv[0]);
   fprintf(stderr,
      "\t-c  - also shuffle the existing .cls file\n");
   fprintf(stderr,
      "\t-m  - write the .mit file that defines the shuffle\n");
   fprintf(stderr,
      "\t-s seed  - specify a seed instead of the default: %d\n", DEFAULTSEED);
   fprintf(stderr,
      "\t-u  - undo: write the .mit file that will undo the shuffle\n");
   fprintf(stderr, "\t     misfiles...\n");
   exit(1);
}
